#
# spec file for package eric
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define distname eric6

# python3-qscintilla isn't available for some Leap versions
# build with PyQt4 instead
%if 0%{?suse_version} <= 1315
%bcond_with qt5
%else
%bcond_without qt5
%endif

%if %{with qt5}
%define qt_ver 5
%define qt_ext -qt%{qt_ver}
%else
%define qt_ver 4
# no qt_ext
%endif

%define qt_dir %{_datadir}/qt%{qt_ver}

Name:           eric
Version:        19.04
Release:        bp156.3.31
Summary:        Python IDE based on Qt5
License:        GPL-3.0-or-later
Group:          Development/Tools/IDE
URL:            https://eric-ide.python-projects.org/
Source:         https://downloads.sourceforge.net/project/eric-ide/%{distname}/stable/%{version}/%{distname}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python3%{?qt_ext}
BuildRequires:  python3-qscintilla%{?qt_ext}
BuildRequires:  python3-xml
BuildRequires:  update-desktop-files
Requires:       python3%{?qt_ext}
Requires:       python3-qscintilla%{?qt_ext}
Requires:       python3-xml
Recommends:     %{name}-api = %{version}
Recommends:     python3-cx_Freeze
Recommends:     python3-doc
Recommends:     python3-enchant >= 1.5.3
Recommends:     python3-pylint >= 0.18.0
Recommends:     python3-pysvn >= 1.7.0
Recommends:     python3-rope >= 0.9.2
Provides:       python-eric5 = %{version}
Obsoletes:      python-eric5 < %{version}
Provides:       python-eric6 = %{version}
Obsoletes:      python-eric6 < %{version}
Provides:       eric5 = %{version}
Obsoletes:      eric5 < %{version}
Provides:       eric6 = %{version}
Obsoletes:      eric6 < %{version}
BuildArch:      noarch

%description
Eric is a Python and Ruby editor and IDE, written in Python. It is
based on the Qt GUI toolkit and integrates the Scintilla editor
control.

%package api
Summary:        API files for eric6
Group:          Development/Tools/IDE
Provides:       python-eric5-api = %{version}
Obsoletes:      python-eric5-api < %{version}
Provides:       python-eric6-api = %{version}
Obsoletes:      python-eric6-api < %{version}
Provides:       eric5-api = %{version}
Obsoletes:      eric5-api < %{version}
Provides:       eric6-api = %{version}
Obsoletes:      eric6-api < %{version}

%description api
This package provides API files for eric6.
If both python-eric6 and python3-eric6 packages are installed then only one
python-eric6-api or python3-eric6-api is needed.

%prep
%setup -q -n %{distname}-%{version}

find . -name \*.py -exec sed -i -e '/^#!\/usr\/bin.*python/d' '{}' \;

%build
# nothing here

%install
python3 install.py -b %{_bindir} -d %{python3_sitelib} -i %{buildroot} -x --pyqt=%{qt_ver}
%fdupes %{buildroot}%{python3_sitelib}
ln -sf eric6 %{buildroot}%{_bindir}/%{name}

%files
%license LICENSE.GPL3
%doc README.rst THANKS
%{_bindir}/*
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/%{distname}.appdata.xml
%{_datadir}/applications/%{distname}.desktop
%{_datadir}/applications/%{distname}_browser.desktop
%{_datadir}/applications/%{distname}_webbrowser.desktop
%{_datadir}/pixmaps/eric.png
%{_datadir}/pixmaps/ericWeb.png
%{python3_sitelib}/

%files api
%license LICENSE.GPL3
%dir %{qt_dir}
%dir %{qt_dir}/qsci/api/python
%{qt_dir}/qsci/api/python/*
%dir %{qt_dir}/qsci/api/ruby
%{qt_dir}/qsci/api/ruby/*
%dir %{qt_dir}/qsci/api/qss
%{qt_dir}/qsci/api/qss/*

%changelog
* Sun Apr  7 2019 seanlew@opensuse.org
- Update to 19.04
  * added a checker for advised forms of the return statement
  * addd extended regex support for C++ 11
  * added capability to configure the subline indent
  * added capability to frame the line containing the cursor
  * added support for sub-styling
  * extended support for keyword sets
* Sun Mar  3 2019 seanlew@opensuse.org
- Update to 19.03
  * added an interface for the conda environment/pkg management
  * suppress auto-completions in various circumstances
  * changed the if from menu based -> widget-based in toolbox
  * extended the environment def by a flag indicting remote access
  * updated pycodestyle to 2.5.0
  * updated pyflakes to 2.1.0
* Mon Feb 18 2019 seanlew@opensuse.org
- Update to 19.02
  * added capability to suppress some markers in the marker map
  * add capability to the multi project browser to remove a project
  * added support to select a client SSL Cert (Qt 5.12)
* Fri Jan 11 2019 seanlew@opensuse.org
- Update to 19.01
  * added entry to select the virt environment of the current proj
  * added support for some resource compiler options
  * added single application mode
  * change logic inside eric to use a browser to show help text
* Sat Dec 29 2018 sean@suspend.net
- Update to 18.12:
  * changed the 'regexp' search option to use POSIX mode
  * added the ability to search for a regex
  * added support for the resource-suffix and --import-from= opts
  * added a button to open the translator config page
  * extended the env definition by a flag indicating an Anaconda env
  * changed the start menu to give a list of defined envs
* Fri Nov  2 2018 sean@suspend.net
- Update to 18.11:
  - IRC
  - -  added support for some of the "/" commands to the user context menu
  - Translator
  - - changed DeepL support to DeepL Pro
  - VCS
  - - added capability to show some VCS information in the main status window
* Tue Oct 23 2018 Hans-Peter Jansen <hpj@urpla.net>
- Update to 18.10:
  - General
  - - changed the extension of the generated script files for Windows
    from '.bat' to '.cmd'
  - Debugger
  - - added code to use the default virtual environment, if none has
    been configured yet
  - IRC
  - - added support for the /query, /notice, /ping, /ignore, /unignore,
    /away, /join, /part and /partall commands
  - Tasks
  - - added code to mark a line as not containing a task with '__NO-TASK__'
* Wed Sep 12 2018 Hans-Peter Jansen <hpj@urpla.net>
- Update to 18.09:
  - bug fixes
  - Mercurial Interface
  - - added support for Mercurial 4.7 extended commands 'graft', 'rebase' and
    'export'
* Fri Aug  3 2018 hpj@urpla.net
- Update to 18.08:
  - bug fixes
  - General
  - - made the activation of these internal tools configurable
  * Template-Viewer
  * File-Browser
  * Symbols
  * Code Documentation Viewer
  * Cooperation
  * IRC
  * Numbers
  - File-Browser
  - - changed code so file-browser is always a standalone window
  - Project Interfaces Browser
  - - added actions to configure some IDL compiler options (-I, -D, -U)
  - Shell
  - - changed code so shell is always a standalone window
  - Translator
  - - added a translation engine for the IBM Watson Language Translator
  - Web Browser (NG)
  - - added default search engine definitions for
  * Qwant
  * StartPage
- Update to 18.07:
  - bug fixes
  - Checkers
  - - upgraded pyflakes to version 2.0.0
  - Debugger
  - - added support of breakpoint() builtin of Python 3.7
  - - added code to try to open the source file if an exception occurred in
    a cython .pyd file
  - Git Interface
  - - added capability to change the URL and/or user credentials for a
    remote repository
  - pip Interface
  - - added support for the '--user' option of install and list commands
  - - changed to use the new VirtualEnv Manager
  - Unit Test
  - - extended the standalone unit test tool to be able to open source in an
    editor window
  - VirtualEnv Manager
  - - added a manager for virtual environments
  - - changed a few places to use the newly introduced virtual environments
    (Note: a new session file format and debug properties file format
  has been introduced)
* Thu Jun  7 2018 hpj@urpla.net
- fix api requires/obsoletes
* Mon Jun  4 2018 hpj@urpla.net
- Update to 18.06:
  - bug fixes
  - Editor
  - - added a configuration option (Editor->Style page) to show the marker map
    on the left or right of the editor
  - - added a context menu for the "fold" margin
  - - improved handling of folded lines when using "go to" functions
  - - resize auto complete list box to fit with contents
  - - added a configuration option (Editor->autocomplete to set up maximum
    width and height of the auto complete list box
  - Shell
  - - resize auto complete list box to fit with contents
  - pip Interface
  - - added an action to install a locally available package/wheel
  - Web Browser (NG)
  - - improved the sending of the "Referer" header like it is done by Firefox
- remove eric-fix-bindir.patch: desktop files install fix is released from
  upstream
* Sun May 27 2018 hpj@urpla.net
- Use build conditionals to select qt version
- Further spec file cleanup
- Fix eric-api recommendation
* Thu May 24 2018 mcepl@suse.com
- Rename files from eric6 to eric, when applicable
- Build with Qt4 on LEAP 42.3
* Mon May 21 2018 hpj@urpla.net
- fix requires/obsoletes
- cleanup spec
* Fri May  4 2018 hpj@urpla.net
- use upstream fix for desktop files
* Tue May  1 2018 hpj@urpla.net
- Update to 18.05:
  - bug fixes
  - General
  - - added the '--disable-plugin=' option to disable plug-ins via the command
    line
  - Code Style Checker
  - - added support for '# noqa' and '# NOQA' comments to suppress warnings
  - - extended the dialog to be able to define the number of blank lines
    before class and function/method definitions
  - Project
  - - added support for 'make' to the Project menu and run it automatically
    before the main script is started (configuration option)
  - Syntax Checker
  - - added support for '# noqa' and '# NOQA' comments to suppress warnings
  - Translator
  - - updated the translator URL for DeepL
  - Web Browser (NG)
  - - improvement of the download manager
  - - added support for the Google Safe Browsing Lookup API (v4)
  - Third Party packages
  - - updated coverage.py to 4.5.1
  - - updated pycodestyle to 2.4.0
  - - updated send2trash to version 1.5.0
- Fix desktop files executable path
* Mon Apr 30 2018 hpj@urpla.net
- Update to 18.04:
  - bug fixes
  - General
  - - added config option to disable the use of the global menu bar on Linux
    Code Style Checker
  - - added checks for default docstring in functions and modules
  - - added check for dictionaries with sorted keys
  - - added checks for logging statements
  - - added check for the 'gettext' import statement
  - - added some checks of the bugbear checker
- Update to 18.03:
  - bug fixes
  - Editor
  - - added support for EditorConfig
  - - added VCS conflict markers to the types shown on the marker map
- Update to 18.02:
  - bug fixes
  - General
  - - extended the session to store/retrieve the split views and the order of
    the editors (Note: The new session file format is not backward compatible
    and cannot be read by eric releases prior to 18.02)
  - - added basic support for Cython
  - Editor
  - - added a context menu entry to "Execute Selection In Console"
  - Web Browser (NG)
  - - added support for HTML5 "Desktop Video Capture" and "Desktop Audio and
    Video Capture" as of Qt 5.10.0/PyQt 5.10.0
  - - added the capability to pause/resume download (Qt 5.10.0/PyQt 5.10.0)
  - - added support for attributes introduced by Qt 5.9 and Qt 5.10
- Rename package to eric6
* Sat Jan  6 2018 termim@gmail.com
- Update to 18.01:
  - bug fixes
  - Debugger / Breakpoint Viewer
  - - added the capability to remember the most recently used file names and
    conditions
  - Editor
  - - added an action to the view menu to clear all folds of the current editor
  - - added an entry to delete all change markers to the marker margin context
    menu
  - Project
  - - If a project does not contain protobuf files, the old project file format
    (5.1) is generated to make the file backward compatible.
  - Plug-ins
  - - added the pip interface plug-in to the core plug-ins
  - - added the virtualenv/pyvenv interface plug-in to the core plug-ins
  - - added the setup.py wizard plug-in to the core plug-ins
  - - added the eric plug-in wizard plug-in to the core plug-ins
  - - added the .desktop wizard plug-in to the core plug-ins
  - - added the translator plug-in to the core plug-ins
  - - added the git plug-in to the core plug-ins
  * *Note**: These plug-ins should be deinstalled via the plug-in
  uninstallation dialog of eric before upgrading eric. A reconfiguration of
  these plug-ins may be neccessary.
  - PluginToolPip
  - PluginWizardVirtualenv
* Thu Jan  4 2018 termim@gmail.com
- fix rpm build
* Tue Dec 26 2017 jengelh@inai.de
- Remove marketing from description.
* Fri Dec  8 2017 fabian@ritter-vogt.de
- Use PyQt5
- Drop python3-sip requires, python-qt5 already requires it
- Run spec-cleaner
- Use full URL for Source:
* Tue Dec  5 2017 termim@gmail.com
- Update to 17.12:
  - bug fixes
  - General
  - - added support for Google protobuf protocol files
  - Code Documentation Viewer
  - - added possibility to show the type of the object info is shown for
  - - modified the top row and the search part in order to allow smaller sizes
  - Debugger / Variables Viewer
  - - introduced a configuration option to limit the variables shown by the
    variables viewers depending on their size (in order to avoid overload
    situations on low power or low memory machines)
  - Styles
  - - added a dark style (*.qss and Python lexers) provided by Giuseppe
    Corbelli
  - Third Party packages
  - - updated send2trash to version 1.4.2
  * *NOTE**: This release introduces a new project file format that will be
    rejected by previous releases. The new format is needed for the Google
    protobuf support.
* Sun Nov 19 2017 termim@gmail.com
- Update to 17.11.1
  - Bug fixes
* Fri Nov  3 2017 termim@gmail.com
- Update to 17.11
  - Debugger:
  - added capability to enter an interpreter in the Start... dialog
  - Editor
  - added support for auto-completion lists being provided asynchronously
  - added a viewer for source code documentation extracted by providers
    to be implemented by plug-ins (like rope and jedi)
  - Web Browser (old style)
  - changed logic in order to put new downloads at the top of the list of
    downloads and added the download date and time to the shown info
  - Web Browser (NG)
  - changed logic in order to put new downloads at the top of the list of
    downloads and added the download date and time to the shown info
* Mon Oct  9 2017 termim@gmail.com
- Update to 17.10
  - bug fixes
  - Web Browser (NG)
  - added a downloader and installer/uninstaller dialog for spell check
    dictionaries
* Fri Sep  1 2017 termim@gmail.com
- Update to 17.09
  - bug fixes
  - Debugger
  - -  unified the Python2 and Python3 debugger interfaces
  - Exporter
  - - extended the HTML exporter to convert Markdown and ReST files to
    HTML
  - Plugin Manager
  - - added a bar with counts for new/local updates/remote updates to the
    plug-in repository dialog
  - Previewers
  - - added capability to configure the output format for the markdown
    and docutils (ReST) previewers
  - Web Browser (NG)
  - - added support for Google Safe Browsing
  - Third Party packages
  - - updated jasy to 1.5-beta5 (latest release available)
- remove i18 tarballs - they are already in the main archive.
* Fri Aug  4 2017 termim@gmail.com
- Update to 17.08
  - bug fixes
  - Shell
  - - added support for different history navigation styles (disabled,
    Linux, Windows)
  - - improved shell history dialog
  - Templates
  - added some new predefined template variables (time, path_name_rel,
    dir_name_rel)
  - Web Browser (NG)
  - - added support for sessions
* Sun Jul  2 2017 termim@gmail.com
- Update to 17.07
  - Background Services
  - - added functionality to limit the number of processes used for
    background services
  - Bug Reporting / Feature Request (Email)
  - - added the capability to send these emails via Google Mail using
    OAuth2 authentication
  - Diff Dialogs
  - -  made the colors of the diff dialogs configurable
  - Third Party packages
  - - updated chardet to 3.0.4
- Update to 17.06
  - bug fixes
  - Checkers
  - - extended the source documentation checker to check for raised/documented
    exceptions and defined/documented signals
  - Editor
  - - reintroduced the highlighting of current instruction line and the error
    line using colored background. It is configurable whether to use these
    backgrounds or the arrows.
  - - added capability to perform the various replace methods via keyboard
    shortcuts
  - Plugin Manager
  - - added an option to cleanup the plug-ins download area during startup
  - Qt Tools
  - - added code to auto-discover the presence of the new 'pyqt5-tools' wheel
    (Windows only) (thanks to Kyle Altendorf for providing this wheel)
  - Web Browser (NG)
  - - united the stop and reload buttons of the navigation bar
  - - added a super menu to modernize the look & feel
  - - added Ctrl-Click and middle click actions to the navigation buttons
    to perform the action in a new tab
* Sat May  6 2017 termim@gmail.com
- Update to 17.05
  - bug fixes
  - Editor
  - - changed the indication of the current instruction line and the error line
    to use a green or red arrow instead of a colored background
  - PyQt Tools
  - - added a configuration option for the path of the PyQt tools
  - Shell
  - - added a standalone shell window
  - Web Browser (NG)
  - - added the last visited time and date to the bookmark properties dialog
  - - added a visit count to the history entries (shown in the history dialog)
  - - made full screen mode really full screen
  - Third Party packages
  - - updated Pygments to 2.2.0
  - - updated chardet to 3.0.2
* Tue Apr 11 2017 termim@gmail.com
- Update to 17.04.1
  - - bug fixes
- Update to 17.04
  - bug fixes
  - General
  - - increased minimum required Python versions to prevent usage
    with very old versions (i.e. eric was never tested with)
    min. versions: Python 2 - 2.7.10; Python 3 - 3.4.0
  - Checkers
  - - added checks for shadowed Python builtins and unneccessary comprehensions
    and generators to the code style checker
  - - added a checker to check for lines of code of too high complexity
  - - added capability to place line flags (e.g. __IGNORE...) on the line
    following the one to be ignored
  - Debugger
  - - shell autocompleter takes the right global variables into account now
  - - move the instruction pointer within the current function (Hotkey: F12)
  - - report syntax and indentation errors raised by an application or module
    in the correct manner
  - - avoid crashes on using greenlets
  - Mercurial Interface
  - - extended the user configuration dialog
  - - added support for the 'zstd' compression for bundles (as of 4.1.0)
- add fetch script fetch-eric.sh
* Sat Mar 11 2017 termim@gmail.com
- Update to 17.03.1
  - bug fixes
* Fri Mar  3 2017 termim@gmail.com
- Update to 17.03
  - Checkers
  - - upgraded pycodestyle to version 2.3.1
  - - upgraded pyflakes to version 1.5.0
  - Debugger
  - - prevent stepping into print statements if checkbox for debugging into
    interpreter libraries is checked
  - - catch unhandled exceptions again
  - - support for PySide2 added
  - - atexit handling works as specified in any condition
  - - prevent ordinary breakpoints to steal the focus from an exception
  - Mercurial Interface
  - - improved the log browser in several ways
  - - improved the status dialog
  - Project
  - - added capability to remember previously used entries in the project
    debugger properties dialog
  - Web Browser (NG)
  - - added support for new options provided by Qt 5.8.0
  - - added support for spell checking as of Qt 5.8.0
* Sun Feb  5 2017 termim@gmail.com
- Update to 17.02.1
  - fixes a regression related to using eric with Qt 4.8.
- Update to 17.02
  - Checkers
  - - upgraded pycodestyle to version 2.2.0+
  - Debugger
  - - changed the variables filter dialog to be more user friendly
  - Editor
  - - added a bar with formatting options for HTML, Markdown and reStructured
    Text files
  - - added support for the new QScintilla JSON lexer
  - - added support for the new QScintilla Markdown lexer
  - Email
  - - added capability to use the SSL encryption method (next to StartTLS) in
    the built in Email dialog
  - Mercurial Interface
  - - added clickable links to the log browser details pane
  - - added up and down buttons to move the current entry to the log browser
  - - added the capability to configure the length of the log message shown
    in the message column of the log browser list
  - Subversion interface
  - - added up and down buttons to move the current entry to the log browser
  - Web Browser
  - - added functionality to manage the plug-in provided documentation sets
* Tue Jan  3 2017 termim@gmail.com
- Update to 17.01
  - bug fixes
  - General
  - - added capability to save a global session to disk and restore it
  - - added capability to save a crash session in order to restore the
    current state in case of a cras
  - - added option to configure the crash session startup behavior and
    added the '--no-crash' option to suppress looking for a crash session
  - - added the '--disable-crash' option to temporarily disable the crash
    session support through the command line
  - - changed some options: --noopen to --no-open, --nosplash to --no-splash
  - Debugger
  - - added capability to edit the history lists of the start dialogs of
    the debugger
  - Editor
  - - added support for project type specific auto-completion and
    calltips including the respective configuration (Editor->APIs page)
* Sat Dec  3 2016 termim@gmail.com
- Update to 16.12
  - Mercurial Interface
  - - added context menu actions to the tags/branches list dialog
  - - added bookmark actions to the Log Browser tools menu
  - - added context menu actions to the bookmark list dialog
  - - added possibility to enter a commit author and commit date/time
  - - added capability to enforce a tagging operation
  - Third Party packages
  - - updated chardet to 2.3.0
* Sun Nov 13 2016 termim@gmail.com
- Update to 16.11
  - bug fixes
  - General
  - - added a status bar icon to show the online status to the main window
  - - added an action to clear the private data of the IDE
  - Checkers
  - - added capaibility to ignore warnings by code (use
    __IGNORE_WARNING_<code>__, e.g. __IGNORE_WARNING_M613__)
  - Debugger
  - - added a debugger interface registry to allow debuggers being
    implemented as plug-ins
  - - Python Debuggers:
  - -- changed the protocol to a JSONRPC style protocol to be more robust
  - -- massive speed gain of the debug client (Tobias Rzepka)
  - -- unified the debugger clients for Python 2 and 3 (Tobias Rzepka)
  - -- unified the standard and threaded debugger clients (Tobias Rzepka)
  - -- added debug support for QThread threads (Tobias Rzepka)
  - - Ruby Debugger:
  - -- removed the Ruby debugger (the interface doesn't work with recent
    Ruby versions anymore)
  - - Call Trace Viewer
  - -- added capability to stop recording upon exit of the client script
  - - Variables Viewer
  - -- added capability to refresh the view via the context menu
  - Hex Editor
  - - added a nice little hex editor tool (usable as a standalone tool
    as well)
  - Icon Editor
  - - added capability to close all other icon editor windows
  - Project
  - - added a dialog to quickly search for files in the list of project files
    (thanks to Mike C. Fletcher for contributing the majority of this)
  - - added an option to rescan the project for tasks upon open
  - Project Browser
  - - added capability to search the file tree via the keyboard (directories and
    files only)
  - Tools
  - - Tray Starter
  - -- added an entry to show the version information
  - Version Control System Interfaces
  - - Mercurial
  - -- added support for pulling and pushing the current bookmark
  - -- added support for the strip extension
  - -- added support for the histedit extension
  - -- added support for the strip and fetch extensions to the log browser
  - -- added an action to the administration menu to clean out the backup
    bundles
  - Web Browser
  - - added capability to remember the zoom values for each site (incl. a
    dialog to manage these)
  - - added a status bar icon to show the online status
  - Web Browser (NG)
  - - ported the web browser to QtWebEngine as of Qt 5.6.0 because starting
    with this version QtWebKit is no longer (officially) supported
  - Third Party packages
  - - updated Pygments to 2.1.3
  - - updated pep8 to 2.1.0dev0 and renamed it to pycodestyle
  - - updated coverage.py to 4.1.0
  - - updated pyflakes to 1.2.3+
* Sun Nov  6 2016 termim@gmail.com
- Update to 6.1.11
  * bug fixes
* Sun Oct  9 2016 termim@gmail.com
- Update to 6.1.10
  * bug fixes
* Sun Sep  4 2016 termim@gmail.com
- Update to 6.1.9
  * bug fixes
* Sun Jul 31 2016 termim@gmail.com
- Update to 6.1.8
  * bug fixes
  * improves compatibility with PyQt5 5.7.0 and above
* Mon Jul  4 2016 termim@gmail.com
- Update to 6.1.7
  * bug fixes
* Sun Jun  5 2016 termim@gmail.com
- Update to 6.1.6
  * bug fixes
* Mon May  9 2016 termim@gmail.com
- Update to 6.1.5
  * bug fixes
  * improved Py2/3 compatibility thanks to Parsifal Herzog
* Wed Apr 13 2016 termim@gmail.com
- Update to 6.1.4
  * bug fixes
* Wed Mar  9 2016 termim@gmail.com
- Update to 6.1.3
  * bug fixes
* Mon Feb  8 2016 termim@gmail.com
- Update to 6.1.2
  * bug fixes
* Thu Jan  7 2016 termim@gmail.com
- Update to 6.1.1
  * bug fixes
* Sat Dec  5 2015 termim@gmail.com
- Update to 6.1.0
- General
  * added a configuration page to edit the list of mime types to
    be opened in an eric editor
  * added the '--settings=' command line switch to store the
    settings files in a non-standard directory
- Checkers
  * added a batch mode to the code style checker to make use of
    multiple CPUs/CPU-Cores
  * added a batch mode to the syntax checker to make use of
    multiple CPUs/CPU-Cores
  * added a batch mode to the indentation checker to make use of
    multiple CPUs/CPU-Cores
  * added a code complexity checker iaw. McCabe to the code style
    checker
  * added miscellaneous checks to the code style checker (coding
    comment, copyright, blind except, print statements, one element
    tuples, __future__ imports, old style string formats, string
    format strings)
- Debugger
  * added signal handlers for the Python debug clients
- Editor
  * added capability to configure the indentation guides colors
  * added capability to ask multiple completion list and call-tip
    providers
  * added support for mouse click handlers to be provided by plug-ins
  * added the search markers to the marker map
  * added capability to save a copy of the editor contents
  * Lexers
  - added support for the new C++ lexer properties (as of
    QScintilla V. 2.9.0)
- File Browser
  * added capability to show imports of a Python script
- Log Viewer
  * added a message filter including a configuration page
- Mini Editor
  * added capability to save a copy of the editor contents
- Preferences Dialog
  * changed the 'filter' function to a 'search' function disabling
    all entries, that don't contain the entered string
  * changed the handling of the configuration page list entries
    to be collapsed on first show and remember the expanded ones
    while eric is running (but not between invocations)
- Previewers
  * added capability to use 'Sphinx' to preview ReST files
- Project
  * added functionality to reorganize the files automatically,
    when the project type or file type associations are changed
- Project Browser
  * added capability to show imports of a Python script
- Source Code Documentor
  * added tags to describe the type of parameters (@type, @ptype)
    and return values (@rtype)
- Task Viewer
  * added capability to add sub-tasks (i.e. a task hierarchy) for
    manually generated tasks
- Tools
  * Diff Dialog
  - added capability to search in the output
- Version Control System Interfaces
  * All
  - added capability to search in the output of Diff dialogs
  * Mercurial
  - enhanced the log browser functionality by a search mode
  - enhanced the log browser functionality by pull and push actions
  - enhanced the status dialog functionality by a diff view
- Web Browser
  * added support for HTML5 feature permissions
  * improved parsing of the content disposition header analog to
    the way it is done in qutebrowser
  * modified and extended the VirusTotal interface for the v2 API
  * added our own web inspector window to overcome a Qt weekness
  * added a manager for Flash Cookies
- Third Party packages
  * updated coverage to 4.0
  * updated Pygments to 2.0.2
* Tue Nov 10 2015 termim@gmail.com
- Update to 6.0.11
  * bug fixes
* Wed Oct 21 2015 termim@gmail.com
- Update to 6.0.10
  * bug fixes
* Wed Sep  9 2015 termim@gmail.com
- Update to 6.0.9
  * bug fixes
* Fri Aug 14 2015 termim@gmail.com
- Update to 6.0.8
  * bug fixes
  * compatibility to PyQt 5.5
* Mon Jul  6 2015 termim@gmail.com
-  Update to 6.0.7
  * bug fixes
* Thu Jun 11 2015 termim@gmail.com
- Update to 6.0.6
  * bug fixes
* Tue May 12 2015 termim@gmail.com
- Update to 6.0.5
  * bug fixes
* Mon Apr 13 2015 termim@gmail.com
- Update to 6.0.4
  * bug fixes
* Mon Mar  2 2015 termim@gmail.com
-  Update to 6.0.3
  * bug fixes
* Fri Feb 20 2015 termim@gmail.com
- Update to 6.0.2
  * bug fixes
* Sun Jan 18 2015 termim@gmail.com
- Update to 6.0.1
  * bug fixes
* Mon Dec 29 2014 termim@gmail.com
- Initial checkin
